[GRASS-SVN] r40299 - grass/trunk/lib/gpde

svn_grass at osgeo.org svn_grass at osgeo.org
Thu Jan 7 08:55:09 EST 2010


Author: huhabla
Date: 2010-01-07 08:55:09 -0500 (Thu, 07 Jan 2010)
New Revision: 40299

Modified:
   grass/trunk/lib/gpde/N_gwflow.c
   grass/trunk/lib/gpde/N_gwflow.h
Log:
balance -> budged

Modified: grass/trunk/lib/gpde/N_gwflow.c
===================================================================
--- grass/trunk/lib/gpde/N_gwflow.h	2010-01-07 13:47:11 UTC (rev 40298)
+++ grass/trunk/lib/gpde/N_gwflow.h	2010-01-07 13:55:09 UTC (rev 40299)
@@ -100,7 +100,7 @@
 					 int col, int row, int depth);
 extern N_data_star *N_callback_gwflow_2d(void *gwdata, N_geom_data * geom,
 					 int col, int row);
-extern void N_gwflow_2d_calc_water_balance(N_gwflow_data2d * data,
+extern void N_gwflow_2d_calc_water_budged(N_gwflow_data2d * data,
         N_geom_data * geom, N_array_2d * balance);
 extern N_gwflow_data3d *N_alloc_gwflow_data3d(int cols, int rows, int depths,
 					      int river, int drain);



More information about the grass-commit mailing list
--- grass/trunk/lib/gpde/N_gwflow.c	2010-01-07 13:47:11 UTC (rev 40298)
+++ grass/trunk/lib/gpde/N_gwflow.c	2010-01-07 13:55:09 UTC (rev 40299)
@@ -538,25 +538,25 @@
 
 
 /* *************************************************************** */
-/* ****************** N_gwflow_2d_calc_water_balance************** */
+/* ****************** N_gwflow_2d_calc_water_budged ************** */
 /* *************************************************************** */
 /*!
  * \brief This function computes the water balance of the entire groundwater
  *
  * The water balance is calculated for each active and dirichlet cell from
  * its surrounding neighbours. This is based on the 5 star mass balance computation
  * of N_callback_gwflow_2d and the gradient of the water heights in the cells.
  * The sum of the water balance of each active/dirichlet cell must be near zero
  * due the effect of numerical inaccuracy of cpu's.
  *
  * \param gwdata N_gwflow_data2d *
  * \param geom N_geom_data *
- * \param balance N_array_2d
+ * \param budged N_array_2d
  * \returnvoid
  *
  * */
 void
-N_gwflow_2d_calc_water_balance(N_gwflow_data2d * data, N_geom_data * geom, N_array_2d * balance)
+N_gwflow_2d_calc_water_budgede(N_gwflow_data2d * data, N_geom_data * geom, N_array_2d * budged)
 {
     int y, x, stat;
     double h, hc;
@@ -607,7 +607,7 @@
 	    else {
 		Rast_set_null_value(&val, 1, DCELL_TYPE);
 	    }
-	    N_put_array_2d_d_value(balance, x, y, val);
+	    N_put_array_2d_d_value(budged, x, y, val);
 	}
     }
 
@@ -538,25 +538,25 @@
 /* *************************************************************** */
 /*!
- * \brief This function computes the water balance of the entire groundwater
+ * \brief This function computes the water budged of the entire groundwater
  *
@@ -538,25 +538,25 @@
  *
- * The water balance is calculated for each active and dirichlet cell from
+ * The water budged is calculated for each active and dirichlet cell from
  * its surrounding neighbours. This is based on the 5 star mass balance computation
  * of N_callback_gwflow_2d and the gradient of the water heights in the cells.
@@ -538,25 +538,25 @@
  * its surrounding neighbours. This is based on the 5 star mass balance computation
  * of N_callback_gwflow_2d and the gradient of the water heights in the cells.
- * The sum of the water balance of each active/dirichlet cell must be near zero
+ * The sum of the water budged of each active/dirichlet cell must be near zero
  * due the effect of numerical inaccuracy of cpu's.
  *

Modified: grass/trunk/lib/gpde/N_gwflow.h
===================================================================